@@ -18,8 +18,7 @@ from shutil import copy
 from shutil import copytree
 from tempfile import mkdtemp
 
-from geo import BoundingBox
-
+from .geo import BoundingBox
 try:
     import ogr
 except ImportError:
